@@ -74,6 +74,14 @@ def test_aliases():
         cairo.SubpixelOrder,
     ]
 
+    if hasattr(cairo, "ColorMode"):
+        # cairo 1.17.8+
+        types_.append(cairo.ColorMode)
+
+    if hasattr(cairo, "Dither"):
+        # cairo 1.18.0+
+        types_.append(cairo.Dither)
+
     def get_prefix(t):
         name = t.__name__
         # special case..
@@ -127,4 +135,4 @@ def test_pickle():
 
     value = cairo.Antialias(42)
     new_value = pickle.loads(pickle.dumps(value))
-    assert type(new_value) == int
+    assert type(new_value) is int
